@@ -4,7 +4,7 @@ use crate::*;
 use vipers::{assert_keys_eq, invariant, unwrap_int, unwrap_opt, Validate};
 
 impl<'info> Validate<'info> for CreateGovernor<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(
             self.smart_wallet.owners.contains(&self.governor.key()),
             GovernorNotFound
@@ -15,13 +15,13 @@ impl<'info> Validate<'info> for CreateGovernor<'info> {
 }
 
 impl<'info> Validate<'info> for CreateProposal<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for ActivateProposal<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.governor, self.proposal.governor);
         assert_keys_eq!(self.electorate, self.governor.electorate);
         invariant!(
@@ -49,7 +49,7 @@ impl<'info> Validate<'info> for ActivateProposal<'info> {
 }
 
 impl<'info> Validate<'info> for CancelProposal<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(
             self.proposer,
             self.proposal.proposer,
@@ -69,7 +69,7 @@ impl<'info> Validate<'info> for CancelProposal<'info> {
 }
 
 impl<'info> Validate<'info> for QueueProposal<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(
             self.governor,
             self.proposal.governor,
@@ -108,13 +108,13 @@ impl<'info> Validate<'info> for QueueProposal<'info> {
 }
 
 impl<'info> Validate<'info> for NewVote<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for SetVote<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.governor.electorate, self.electorate);
         assert_keys_eq!(
             self.governor,
@@ -135,14 +135,14 @@ impl<'info> Validate<'info> for SetVote<'info> {
 }
 
 impl<'info> Validate<'info> for CreateProposalMeta<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.proposer, self.proposal.proposer);
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for SetGovernanceParams<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(
             self.smart_wallet,
             self.governor.smart_wallet,
